@@ -107,37 +107,37 @@ pygi_struct_foreign_lookup (GIBaseInfo *base_info)
 }
 
 PyObject *
-pygi_struct_foreign_convert_to_g_argument (PyObject       *value,
-                                           GITypeInfo     *type_info,
-                                           GITransfer      transfer,
+pygi_struct_foreign_convert_to_g_argument (PyObject        *value,
+                                           GIInterfaceInfo *interface_info,
+                                           GITransfer       transfer,
                                            GIArgument      *arg)
 {
-    GIBaseInfo *base_info = g_type_info_get_interface (type_info);
+    PyObject *result;
+
+    GIBaseInfo *base_info = (GIBaseInfo *) interface_info;
     PyGIForeignStruct *foreign_struct = pygi_struct_foreign_lookup (base_info);
-    g_base_info_unref (base_info);
 
-    if (foreign_struct == NULL)
-        return NULL;
+    if (foreign_struct == NULL) {
+        PyErr_Format(PyExc_KeyError, "could not find foreign type %s",
+                     g_base_info_get_name (base_info));
+        return FALSE;
+    }
 
-    if (!foreign_struct->to_func (value, type_info, transfer, arg))
-        return NULL;
-
-    Py_RETURN_NONE;
+    result = foreign_struct->to_func (value, interface_info, transfer, arg);
+    return result;
 }
 
 PyObject *
-pygi_struct_foreign_convert_from_g_argument (GITypeInfo *type_info,
-                                             GIArgument  *arg)
+pygi_struct_foreign_convert_from_g_argument (GIInterfaceInfo *interface_info,
+                                             GIArgument      *arg)
 {
-    GIBaseInfo *base_info = g_type_info_get_interface (type_info);
+    GIBaseInfo *base_info = (GIBaseInfo *) interface_info;
     PyGIForeignStruct *foreign_struct = pygi_struct_foreign_lookup (base_info);
-    g_base_info_unref (base_info);
-
 
     if (foreign_struct == NULL)
         return NULL;
 
-    return foreign_struct->from_func (type_info, arg);
+    return foreign_struct->from_func (interface_info, arg);
 }
 
 PyObject *
@@ -152,10 +152,7 @@ pygi_struct_foreign_release (GIBaseInfo *base_info,
     if (!foreign_struct->release_func)
         Py_RETURN_NONE;
 
-    if (!foreign_struct->release_func (base_info, struct_))
-        return NULL;
-
-    Py_RETURN_NONE;
+    return foreign_struct->release_func (base_info, struct_);
 }
 
 void
