@@ -157,6 +157,9 @@ class TestEverything(unittest.TestCase):
         # test that there are no duplicates returned
         self.assertEqual(len(attr_list), len(set(attr_list)))
 
+    def test_ptrarray(self):
+        self.assertEquals (Everything.test_garray_container_return(), ['regress'])
+
 class TestNullableArgs(unittest.TestCase):
     def test_in_nullable_hash(self):
         Everything.test_ghash_null_in(None)
@@ -472,3 +475,30 @@ class TestAdvancedInterfaces(unittest.TestCase):
         self.assertTrue(isinstance(obj1, Everything.TestObj))
         self.assertTrue(isinstance(obj2, Everything.TestObj))
         self.assertNotEqual(obj1, obj2)
+
+    def test_obj_skip_return_val(self):
+        obj = Everything.TestObj();
+        ret = obj.skip_return_val(50, 42.0, 60, 2, 3);
+        self.assertEquals(len(ret), 3);
+        self.assertEquals(ret[0], 51);
+        self.assertEquals(ret[1], 61);
+        self.assertEquals(ret[2], 32);
+
+    def test_obj_skip_return_val_no_out(self):
+        obj = Everything.TestObj();
+        # raises an error for 0, succeeds for any other value
+        self.assertRaises(GLib.GError, obj.skip_return_val_no_out, 0)
+
+        ret = obj.skip_return_val_no_out(1)
+        self.assertEquals(ret, None)
+
+class TestSignals(unittest.TestCase):
+    def test_object_param_signal(self):
+        obj = Everything.TestObj();
+
+        def callback (obj_param):
+            self.assertEquals(obj_param.props.int, 3)
+            self.assertEquals(obj_param.__grefcount__, 2)
+
+        obj.connect('sig-with-obj', callback)
+        obj.emit_sig_with_obj()
